==> abills-0.32.tgz: abills/language/english.pl <==
# 0.3
$CHARSET = 'windows-1251';

@PERIODS=('Today', 'Yesterday', 'Week', 'Month', 'All sessions', 'From activization');
@MONTHES=('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August',  'September', 'October', 'November', 'Decembe');
@WEEKDAYS=('Hollidays', 'Mo', 'Tu', 'Wn', 'Th', 'Fr', 'Sat', 'Sun');

$_ADD='Add';
$_GET='Get';
$_GETED='Geted';
$_DEL='Delete';
$_CHANGE='Change';
$_CHANGING='Changing';
$_ADDED='Added';
$_DELETED='Deleted';
$_CHANGED='Changed';
$_ROWS='Rows';
$_FEES='Fees';
$_SIMULTANEOUSLY='Simultaneously';
$_MONETARY_UNIT='Monetary unit';
$_INPAYMENTS ='Inpayments';
$_BACK_PAY='Return';
$_BACK_MONEY='Money return';
$_NOT_EXIST='Not exist';
$_SEND_MAIL='Send e-mail';
$_MESSAGE='Text';
$_MESSAGES='Messages';
$_MESSAGES_DESCRIBE='         .';
$_SUBJECT='Subject';
$_DEPOSIT='Deposit';
$_ACTIVATE='Activisation';
$_ACTIV='Active';
$_SEND='Send';
$_SENDED='Sended';
$_TO_USER='To user';
$_MAIL_BOX='Mail box';
$_WRONG_EMAIL='Wrong E-mail';
$_ERROR_LOG='Error log';
$_FIO='Firstname, Lastname ';
$_ADDRESS='Address';
$_PHONE='Phone';
$_COMMENTS='Comments';
$_REGISTRATION='Registration';
$_EXPIRE='Expire';

$_USER_INFO='User Information';
$_TOTAL='Total';
$_USERS='Users';
$_USER='User';
$_NAME='Name';
$_VARIANT='Tarif Plan';
$_VARIANTS='Tarif Plans';
$_PREPAID='Prepaid';
$_TRAFIC_TARIFS='Traffic tarifs';
$_YEAR='Year';
$_DAY='Day';
$_WEEK='Week';
$_MONTH='Month';
$_CREDIT='Credit';
$_SUM='Sum';
$_NO_SUM='Enter sum';
$_PAYMENTS='Payments';
$_NUM='Number';
$_DESCRIBE='Describe';
$_OPERATOR='Operator';
$_DATE='Date';
$_OPTIONS='Options';
$_STATS='Statictics';
$_FROM='From';
$_TO='To';
$_DELETE_USER='Delete user';
$_DELETED_USER='User deleted';
$_PAYMENT_DELETED='Payments delete';
$_PAYMENT_ADDED='Peyment added';
$_PAYMENT_NOTEXIST='Payment not exist';
$_USER_EXIST='User exist';
$_USER_NOT_EXIST='User not exist';
$_SELECT_USER='SELECT user';
$_RECORDS='Records';
$_WRONG_PASSWD='Wrong password ';
$_LOGOUT='Logout';
$_TRAFFIC='Traffic';
$_DURATION='Duration';
$_DAY_DURATION='Day time limit';
$_LOGIN='Login';
$_LOGINS='Sessions';
$_PASSWD='Password';
$_CONFIRM='Confirmation';

$_ENTER='Enter';
$_BALANCE='Balance';
$_PERIOD='Period';
$_SENT='Sent';
$_RECV='Received';
$_LAST_PAYMENT='Late payment';
$_LAST_LOGIN='Last session';
$_LAST='Last sessions';
$_NOT_LOGINED='Not logined';
$_WELCOME='Welcome';
$_SHOW='Show';
$_SESSIONS='Sessions';
$_SESSION_ID='Session ID';
$_PER_MONTH='Per month';

$_HOUR_TARIF='Time tariff';
$_BYTE_TARIF='Traffic tariff';
$_TRAFFIC='Traffic';
$_MONTH_FEE='Month fee';
$_DAY_FEE='Day fee';
$_UPLIMIT='Alert';
$_BEGIN='Begin';
$_END='END';

$_EXIST='Exist';
$_COUNT='count';
$_CREDITORS='Creditors';
$_PERMISSION='Permisions';

#Online
$_HANGUP='Hangup';
$_HANGUPED='Hanguped';
#Other
$_OTHER='Other';
$_SQL_BACKUP='SQL backup';
$_ADMIN='Administrator';
$_ADMINS='Administrators';
$_GROUPS='Groups';
$_GROUP='Group';
$_CHANGE_PASSWD='Change password';
$_GEN_PASSWD='Gen password';
$_CONFIRM_PASSWD='Confirm password';
$_MAKE_BACKAUP='Make backup';
$_SIZE='Size';
$_LENGTH='Length';

$_MIN='Min';
$_AVG='AVG';
$_MAX='';
$_INTERVALS='Intervals';
$_NO_RECORD='Records not exist';

#leased

$_TIME_LIMIT='Time limit';
$_TRAF_LIMIT='Traffic limit';

$_LIMIT = 'Limit';
$_SPEED = 'Speed';
$_STATUS = 'Status';
$_TIME = 'Time';
$_USED='Used';
$_REMAIN='Remain';
$_SET='Set';
$_RESET='Reset';
$_RESETED='Reseted';
$_FILTERS='Filters';
$_DOCS='Documents';
$_NAS_CONFIG='NAS configuration';
$_NAS_STATISTIC='NAS statistic';
$_NAS='NAS';
$_NASS='NAS';
$_PORT='Port';
$_REDUCTION='Reduction';


$_SEARCH='Search';
$_TEXT='Text';
$_TYPE='Type';
$_RESULT='Result';
$_PARAM='Parameter';
$_PARAMS='Parameters';
$_VALUE='Value';
$_FILE='File';
$_TEMPLATES='Template';


$_ERROR = 'Error';
$_INFO = 'Information';
$_CUSTOMERS='Customers';
$_ACCOUNTS= 'Accounts';
$_ACCOUNT='Account';
$_CREATE='Create';
$_CREATED='Created';
$_CUSTOMER='Customer';
$_PRE='Preview';
$_ORDER='Order';
$_PRINT='Print';
$_ACCOUNT_EXIST='Account exist';
$_SDETAIL='Sessions detalization';
$_DETAIL='Detail';

$_AUTH='Authorization';
$_SHORT_NAME="Short name";
$_MANAGE = 'Manage';

$_SHOW_ALL = 'Show all';
$_CARD_SERVICE = 'Internet Carts';
$_ICARDS= 'Internet carts';
$_PAY_CARDS = 'payment carts';
$_PREFIX = 'Prefix';
$_AGE='Age';
$_DAYS='Days';
$_HOURS='Hours';
$_ALL='All';
$_STATE = 'State';
$_EXCHANGE_RATE = "Exchange rate";
$_MONEY = 'Money';
$_REPLY = 'Reply';

$_BANK_INFO='BANK';
$_TAX_NUMBER='Indetificator';
$_BANK_NAME='Bank name';
$_COR_BANK_ACCOUNT='Cor acct';
$_BANK_BIC='BIK';
$_PROFILE='Profile';

#Day of week
$_HOSTS='Hosts';
$_NETWORKS='Networks';
$_HOLIDAYS = 'Holidays';
$_DUNES='Windows Error codes (DUNES)';
$_ALLOW_NAS = 'Allow NAS';
$_ALLOW='Allow';
$_ALLOW_ALL = 'Allow all';
$_DEFAULT='Default';
$_GO = 'Go';
$_LANGUAGE='Language';
$_REVISION='Revision';
$_LOG='History';
$_SHEDULE='Shedule';

$ERR_SELECT_VARIANT='Select variant';
$ERR_WRONG_NAME='Wrong name';
$ERR_ENTER_USER_NAME='Enter user login';
$ERR_SHORT_PASSWD='Short password. Minimum 6 symbols';
$ERR_WRONG_CONFIRM='Wrong Confirmation';
$ERR_NAME_TOOLONG='Login is too long';


#Mail section
$_MAILBOXES='Mailboxes';
$_ALIASES = 'Aliases';
$_DOMAINS='Domains';
$_DOMAIN='Domain';
$_RELAYS='Relay',
$_ACCESS='Access';
$_TRANSPORT = 'Transport';
$_BILLING = 'Billing';
$_ANTIVIRUS='Antyvirus';
$_ANTISPAM='Antispam';
$_FOLDER='Folder';

#==new
$_LIST='List';
$_SA_ONLY = 'Self added only';
$_REPORTS = 'Reports';
$_MODULES = 'Modules';
$_SYSTEM = 'System configuration';
$_GENERED_PARRWORD = 'Genered password';
$_TARIF_PLANS='Tarif plans';
$_TARIF_PLAN='Tarif plan';
$_DISABLE='Disable';
$_ENABLE='Enable';
$_COMPANY='Company';
$_ADD_USER='Add user';
$_CREDIT_TRESSHOLD='Credit Tresshold';
$_SERVICES='Services';
$_FUNCTIONS_LIST='Functions list';
$_COMPANY='Company';
$_OCTETS_DIRECTION='Octets direction';
$_PAYMENT_METHOD='Payment Method';
$_TEST='Test';
$_ZAPED='Zaped';
$_CLOSED='Closed';
$_USED='Use';
$_MAX_SESSION_DURATION='Max. session time';
$_START='Start';
$_YES='Yes';
$_NO='No';
$_PAYMENT_TYPE='Payment type';
$_PREPAID='Prepaid';
$_POSTPAID='Postpaid';
$_MIN_SESSION_COST='Min. session cost';
$_NOW='Now';
$_MONITORING='Monitoring';
$_BILLS='Money accounts';
$_BILL='Money account';
$_TAKE='Take';
$_ADDRESS_STREET='Street';
$_ADDRESS_BUILD='Build';
$_ADDRESS_FLAT='Flat';
$_CONTRACT_ID='Contract Number';
$_NOT_ACTIVE='Not Active';
$_REFRESH='Refresh';
$_ROUTES='Routes';
$_DICTIONARY='Dictionary';
$_ABON='Periodic payments';

$_SYMBOLS='Symbols';
$_SERIAL='Serial';
$_BRUTE_ATACK='Brute Attack';

==> abills-0.35.tgz: abills/language/english.pl <==
# 0.3
$CHARSET = 'windows-1251';

@PERIODS=('Today', 'Yesterday', 'Week', 'Month', 'All sessions', 'From activization');
@MONTHES=('January', 'February', 'March', 'April', 'May', 'June', 'July', 'August',  'September', 'October', 'November', 'Decembe');
@WEEKDAYS=('Hollidays', 'Mo', 'Tu', 'Wn', 'Th', 'Fr', 'Sat', 'Sun');

$_ADD='Add';
$_GET='Get';
$_GETED='Geted';
$_DEL='Delete';
$_CHANGE='Change';
$_CHANGING='Changing';
$_ADDED='Added';
$_DELETED='Deleted';
$_CHANGED='Changed';
$_ROWS='Rows';
$_FEES='Fees';
$_SIMULTANEOUSLY='Simultaneously';
$_MONETARY_UNIT='Monetary unit';
$_INPAYMENTS ='Inpayments';
$_BACK_PAY='Return';
$_BACK_MONEY='Money return';
$_NOT_EXIST='Not exist';
$_SEND_MAIL='Send e-mail';
$_MESSAGE='Text';
$_MESSAGES='Messages';
$_MESSAGES_DESCRIBE='         .';
$_SUBJECT='Subject';
$_DEPOSIT='Deposit';
$_ACTIVATE='Activation';
$_ACTIV='Active';
$_SEND='Send';
$_SENDED='Sended';
$_TO_USER='To user';
$_MAIL_BOX='Mail box';
$_WRONG_EMAIL='Wrong E-mail';
$_ERROR_LOG='Error log';
$_FIO='Firstname, Lastname ';
$_ADDRESS='Address';
$_PHONE='Phone';
$_COMMENTS='Comments';
$_REGISTRATION='Registration';
$_EXPIRE='Expire';

$_USER_INFO='User Information';
$_TOTAL='Total';
$_USERS='Users';
$_USER='User';
$_NAME='Name';
$_VARIANT='Tarif Plan';
$_VARIANTS='Tarif Plans';
$_PREPAID='Prepaid';
$_TRAFIC_TARIFS='Traffic tarifs';
$_YEAR='Year';
$_DAY='Day';
$_WEEK='Week';
$_MONTH='Month';
$_CREDIT='Credit';
$_SUM='Sum';
$_NO_SUM='Enter sum';
$_PAYMENTS='Payments';
$_NUM='Number';
$_DESCRIBE='Describe';
$_OPERATOR='Operator';
$_DATE='Date';
$_OPTIONS='Options';
$_STATS='Statistics';
$_FROM='From';
$_TO='To';
$_DELETE_USER='Delete user';
$_DELETED_USER='User deleted';
$_PAYMENT_DELETED='Payments delete';
$_PAYMENT_ADDED='Peyment added';
$_PAYMENT_NOTEXIST='Payment not exist';
$_USER_EXIST='User exist';
$_USER_NOT_EXIST='User not exist';
$_SELECT_USER='SELECT user';
$_RECORDS='Records';
$_WRONG_PASSWD='Wrong password ';
$_LOGOUT='Logout';
$_TRAFFIC='Traffic';
$_DURATION='Duration';
$_DAY_DURATION='Day time limit';
$_LOGIN='Login';
$_LOGINS='Logins';
$_PASSWD='Password';
$_CONFIRM='Confirmation';

$_ENTER='Enter';
$_BALANCE='Balance';
$_PERIOD='Period';
$_SENT='Sent';
$_RECV='Received';
$_LAST_PAYMENT='Late payment';
$_LAST_LOGIN='Last session';
$_LAST='Last sessions';
$_NOT_LOGINED='Not logined';
$_WELCOME='Welcome';
$_SHOW='Show';
$_SESSIONS='Sessions';
$_SESSION_ID='Session ID';
$_PER_MONTH='Per month';

$_HOUR_TARIF='Time tariff';
$_BYTE_TARIF='Traffic tariff';
$_TRAFFIC='Traffic';
$_MONTH_FEE='Month fee';
$_DAY_FEE='Day fee';
$_UPLIMIT='Alert';
$_BEGIN='Begin';
$_END='END';

$_EXIST='Exist';
$_COUNT='Count';
$_CREDITORS='Creditors';
$_PERMISSION='Permisions';

#Online
$_HANGUP='Hangup';
$_HANGUPED='Hanguped';
#Other
$_OTHER='Other';
$_SQL_BACKUP='SQL backup';
$_ADMIN='Administrator';
$_ADMINS='Administrators';
$_GROUPS='Groups';
$_GROUP='Group';
$_CHANGE_PASSWD='Change password';
$_GEN_PASSWD='Gen password';
$_CONFIRM_PASSWD='Confirm password';
$_MAKE_BACKAUP='Make backup';
$_SIZE='Size';
$_LENGTH='Length';

$_MIN='Min';
$_AVG='AVG';
$_MAX='';
$_INTERVALS='Intervals';
$_NO_RECORD='Records not exist';

#leased

$_TIME_LIMIT='Time limit';
$_TRAF_LIMIT='Traffic limit';

$_LIMIT = 'Limit';
$_SPEED = 'Speed';
$_STATUS = 'Status';
$_TIME = 'Time';
$_USED='Used';
$_REMAIN='Remain';
$_SET='Set';
$_RESET='Reset';
$_RESETED='Reseted';
$_FILTERS='Filters';
$_DOCS='Documents';
$_NAS_CONFIG='NAS configuration';
$_NAS_STATISTIC='NAS statistic';
$_NAS='NAS';
$_NASS='NAS';
$_PORT='Port';
$_REDUCTION='Reduction';


$_SEARCH='Search';
$_TEXT='Text';
$_TYPE='Type';
$_RESULT='Result';
$_PARAM='Parameter';
$_PARAMS='Parameters';
$_VALUE='Value';
$_FILE='File';
$_TEMPLATES='Template';


$_ERROR = 'Error';
$_INFO = 'Information';
$_CUSTOMERS='Customers';
$_ACCOUNTS= 'Accounts';
$_ACCOUNT='Account';
$_INVOICE='Invoice';
$_CREATE='Create';
$_CREATED='Created';
$_CUSTOMER='Customer';
$_PRE='Preview';
$_ORDER='Order';
$_PRINT='Print';
$_ACCOUNT_EXIST='Account exist';
$_SDETAIL='Sessions detalization';
$_DETAIL='Detail';

$_AUTH='Authorization';
$_SHORT_NAME="Short name";
$_MANAGE = 'Manage';

$_SHOW_ALL = 'Show all';
$_CARD_SERVICE = 'Internet Carts';
$_ICARDS= 'Internet carts';
$_PAY_CARDS = 'payment carts';
$_PREFIX = 'Prefix';
$_AGE='Age';
$_DAYS='Days';
$_HOURS='Hours';
$_ALL='All';
$_STATE = 'State';
$_EXCHANGE_RATE = "Exchange rate";
$_MONEY = 'Money';
$_REPLY = 'Reply';

$_BANK_INFO='BANK';
$_TAX_NUMBER='Indetificator';
$_BANK_NAME='Bank name';
$_COR_BANK_ACCOUNT='Cor acct';
$_BANK_BIC='BIK';
$_PROFILE='Profile';

#Day of week
$_HOSTS='Hosts';
$_NETWORKS='Networks';
$_HOLIDAYS = 'Holidays';
$_DUNES='Windows Error codes (DUNES)';
$_ALLOW_NAS = 'Allow NAS';
$_ALLOW='Allow';
$_ALLOW_ALL = 'Allow all';
$_DEFAULT='Default';
$_GO = 'Go';
$_LANGUAGE='Language';
$_REVISION='Revision';
$_LOG='History';
$_SHEDULE='Shedule';

$ERR_SELECT_VARIANT='Select variant';
$ERR_WRONG_NAME='Wrong name';
$ERR_ENTER_USER_NAME='Enter user login';
$ERR_SHORT_PASSWD='Short password. Minimum 6 symbols';
$ERR_WRONG_CONFIRM='Wrong Confirmation';
$ERR_NAME_TOOLONG='Login is too long';
$ERR_WRONG_DATA="Wrong data input";


#Mail section
$_MAILBOXES='Mailboxes';
$_ALIASES = 'Aliases';
$_DOMAINS='Domains';
$_DOMAIN='Domain';
$_RELAYS='Relay',
$_ACCESS='Access';
$_TRANSPORT = 'Transport';
$_BILLING = 'Billing';
$_ANTIVIRUS='Antyvirus';
$_ANTISPAM='Antispam';
$_FOLDER='Folder';

#==new
$_LIST='List';
$_SA_ONLY = 'Self added only';
$_REPORTS = 'Reports';
$_MODULES = 'Modules';
$_SYSTEM = 'System configuration';
$_GENERED_PARRWORD = 'Genered password';
$_TARIF_PLANS='Tarif plans';
$_TARIF_PLAN='Tarif plan';
$_DISABLE='Disable';
$_ENABLE='Enable';
$_COMPANY='Company';
$_ADD_USER='Add user';
$_CREDIT_TRESSHOLD='Credit Tresshold';
$_SERVICES='Services';
$_FUNCTIONS_LIST='Functions list';
$_COMPANY='Company';
$_OCTETS_DIRECTION='Octets direction';
$_PAYMENT_METHOD='Payment Method';
$_TEST='Test';
$_ZAPED='Zaped';
$_CLOSED='Closed';
$_USED='Use';
$_MAX_SESSION_DURATION='Max. session time';
$_START='Start';
$_YES='Yes';
$_NO='No';
$_PAYMENT_TYPE='Payment type';
$_PREPAID='Prepaid';
$_POSTPAID='Postpaid';
$_MIN_SESSION_COST='Min. session cost';
$_NOW='Now';
$_MONITORING='Monitoring';
$_BILLS='Money accounts';
$_BILL='Money account';
$_TAKE='Take';
$_ADDRESS_STREET='Street';
$_ADDRESS_BUILD='Build';
$_ADDRESS_FLAT='Flat';
$_CONTRACT_ID='Contract Number';
$_NOT_ACTIVE='Not Active';
$_REFRESH='Refresh';
$_ROUTES='Routes';
$_DICTIONARY='Dictionary';
$_ABON='Periodic payments';

$_SYMBOLS='Symbols';
$_SERIAL='Serial';
$_BRUTE_ATACK='Brute Attack';
$_CHAPTERS='Chapter';
$_DOWNLOAD='Download';

$_DILLERS='Dillers';

$_VAT='Vat';
$_BONUS='Bonus';
$_PERCENTAGE='Percentage';
$_MULTIUSER_OP='Multiuser operation';
$_RETURNED='Returned';

$_CASH='Cash';
